# maintain-website-tool

A tool to make it simpler to maintain a website against the increasing entropy on the web.

This tool includes:
- A link checker
- A CLI Interface
- A visualization of the links on a website
